import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.LEDForwardVoltage import LEDForwardVoltage
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class DigitalOutput(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()
		self._setDutyCycle_async = None
		self._onsetDutyCycle_async = None
		self._setLEDCurrentLimit_async = None
		self._onsetLEDCurrentLimit_async = None
		self._setState_async = None
		self._onsetState_async = None

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def getDutyCycle(self):
		_DutyCycle = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getDutyCycle
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DutyCycle))

		if result > 0:
			raise PhidgetException(result)

		return _DutyCycle.value

	def setDutyCycle(self, DutyCycle):
		_DutyCycle = ctypes.c_double(DutyCycle)

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_setDutyCycle
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DutyCycle)

		if result > 0:
			raise PhidgetException(result)


	def getMinDutyCycle(self):
		_MinDutyCycle = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getMinDutyCycle
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDutyCycle))

		if result > 0:
			raise PhidgetException(result)

		return _MinDutyCycle.value

	def getMaxDutyCycle(self):
		_MaxDutyCycle = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getMaxDutyCycle
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDutyCycle))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDutyCycle.value

	def setDutyCycle_async(self, DutyCycle, asyncHandler):
		_DutyCycle = ctypes.c_double(DutyCycle)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_setDutyCycle_async
		__func(self.handle, _DutyCycle, _asyncHandler, _ctx)


	def enableFailsafe(self, failsafeTime):
		_failsafeTime = ctypes.c_uint32(failsafeTime)

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_enableFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _failsafeTime)

		if result > 0:
			raise PhidgetException(result)


	def getMinFailsafeTime(self):
		_MinFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getMinFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MinFailsafeTime.value

	def getMaxFailsafeTime(self):
		_MaxFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getMaxFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFailsafeTime.value

	def getFrequency(self):
		_Frequency = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getFrequency
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Frequency))

		if result > 0:
			raise PhidgetException(result)

		return _Frequency.value

	def setFrequency(self, Frequency):
		_Frequency = ctypes.c_double(Frequency)

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_setFrequency
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Frequency)

		if result > 0:
			raise PhidgetException(result)


	def getMinFrequency(self):
		_MinFrequency = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getMinFrequency
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFrequency))

		if result > 0:
			raise PhidgetException(result)

		return _MinFrequency.value

	def getMaxFrequency(self):
		_MaxFrequency = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getMaxFrequency
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFrequency))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFrequency.value

	def getLEDCurrentLimit(self):
		_LEDCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getLEDCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_LEDCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _LEDCurrentLimit.value

	def setLEDCurrentLimit(self, LEDCurrentLimit):
		_LEDCurrentLimit = ctypes.c_double(LEDCurrentLimit)

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_setLEDCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _LEDCurrentLimit)

		if result > 0:
			raise PhidgetException(result)


	def getMinLEDCurrentLimit(self):
		_MinLEDCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getMinLEDCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinLEDCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MinLEDCurrentLimit.value

	def getMaxLEDCurrentLimit(self):
		_MaxLEDCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getMaxLEDCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxLEDCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MaxLEDCurrentLimit.value

	def setLEDCurrentLimit_async(self, LEDCurrentLimit, asyncHandler):
		_LEDCurrentLimit = ctypes.c_double(LEDCurrentLimit)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_setLEDCurrentLimit_async
		__func(self.handle, _LEDCurrentLimit, _asyncHandler, _ctx)


	def getLEDForwardVoltage(self):
		_LEDForwardVoltage = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getLEDForwardVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_LEDForwardVoltage))

		if result > 0:
			raise PhidgetException(result)

		return _LEDForwardVoltage.value

	def setLEDForwardVoltage(self, LEDForwardVoltage):
		_LEDForwardVoltage = ctypes.c_int(LEDForwardVoltage)

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_setLEDForwardVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _LEDForwardVoltage)

		if result > 0:
			raise PhidgetException(result)


	def resetFailsafe(self):
		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_resetFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getState(self):
		_State = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_getState
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_State))

		if result > 0:
			raise PhidgetException(result)

		return _State.value

	def setState(self, State):
		_State = ctypes.c_int(State)

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_setState
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _State)

		if result > 0:
			raise PhidgetException(result)


	def setState_async(self, State, asyncHandler):
		_State = ctypes.c_int(State)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetDigitalOutput_setState_async
		__func(self.handle, _State, _asyncHandler, _ctx)




import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class PHSensor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._PHChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._PHChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._PHChange = None
		self._onPHChange = None

		__func = PhidgetSupport.getDll().PhidgetPHSensor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localPHChangeEvent(self, handle, userPtr, PH):
		if self._PHChange == None:
			return
		self._PHChange(self, PH)

	def setOnPHChangeHandler(self, handler):
		if handler == None:
			self._PHChange = None
			self._onPHChange = None
		else:
			self._PHChange = handler
			self._onPHChange = self._PHChangeFactory(self._localPHChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetPHSensor_setOnPHChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPHChange, None)
		except RuntimeError:
			self._PHChange = None
			self._onPHChange = None

	def getCorrectionTemperature(self):
		_CorrectionTemperature = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getCorrectionTemperature
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CorrectionTemperature))

		if result > 0:
			raise PhidgetException(result)

		return _CorrectionTemperature.value

	def setCorrectionTemperature(self, CorrectionTemperature):
		_CorrectionTemperature = ctypes.c_double(CorrectionTemperature)

		__func = PhidgetSupport.getDll().PhidgetPHSensor_setCorrectionTemperature
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CorrectionTemperature)

		if result > 0:
			raise PhidgetException(result)


	def getMinCorrectionTemperature(self):
		_MinCorrectionTemperature = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMinCorrectionTemperature
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinCorrectionTemperature))

		if result > 0:
			raise PhidgetException(result)

		return _MinCorrectionTemperature.value

	def getMaxCorrectionTemperature(self):
		_MaxCorrectionTemperature = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMaxCorrectionTemperature
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxCorrectionTemperature))

		if result > 0:
			raise PhidgetException(result)

		return _MaxCorrectionTemperature.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetPHSensor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetPHSensor_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getPH(self):
		_PH = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getPH
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PH))

		if result > 0:
			raise PhidgetException(result)

		return _PH.value

	def getMinPH(self):
		_MinPH = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMinPH
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPH))

		if result > 0:
			raise PhidgetException(result)

		return _MinPH.value

	def getMaxPH(self):
		_MaxPH = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMaxPH
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPH))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPH.value

	def getPHChangeTrigger(self):
		_PHChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getPHChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PHChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _PHChangeTrigger.value

	def setPHChangeTrigger(self, PHChangeTrigger):
		_PHChangeTrigger = ctypes.c_double(PHChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetPHSensor_setPHChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _PHChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinPHChangeTrigger(self):
		_MinPHChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMinPHChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPHChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinPHChangeTrigger.value

	def getMaxPHChangeTrigger(self):
		_MaxPHChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPHSensor_getMaxPHChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPHChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPHChangeTrigger.value



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.CodeInfo import CodeInfo
from Phidget22.IRCodeEncoding import IRCodeEncoding
from Phidget22.IRCodeLength import IRCodeLength
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class IR(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._CodeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_uint32, ctypes.c_int)
		else:
			self._CodeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_uint32, ctypes.c_int)
		self._Code = None
		self._onCode = None

		if sys.platform == 'win32':
			self._LearnFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.POINTER(CodeInfo))
		else:
			self._LearnFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.POINTER(CodeInfo))
		self._Learn = None
		self._onLearn = None

		if sys.platform == 'win32':
			self._RawDataFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_int32), ctypes.c_int32)
		else:
			self._RawDataFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_int32), ctypes.c_int32)
		self._RawData = None
		self._onRawData = None

		__func = PhidgetSupport.getDll().PhidgetIR_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localCodeEvent(self, handle, userPtr, code, bitCount, isRepeat):
		if self._Code == None:
			return
		code = code.decode('utf-8')
		self._Code(self, code, bitCount, isRepeat)

	def setOnCodeHandler(self, handler):
		if handler == None:
			self._Code = None
			self._onCode = None
		else:
			self._Code = handler
			self._onCode = self._CodeFactory(self._localCodeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetIR_setOnCodeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onCode, None)
		except RuntimeError:
			self._Code = None
			self._onCode = None

	def _localLearnEvent(self, handle, userPtr, code, codeInfo):
		if self._Learn == None:
			return
		code = code.decode('utf-8')
		if codeInfo != None:
			codeInfo = codeInfo.contents
			codeInfo.toPython()
		self._Learn(self, code, codeInfo)

	def setOnLearnHandler(self, handler):
		if handler == None:
			self._Learn = None
			self._onLearn = None
		else:
			self._Learn = handler
			self._onLearn = self._LearnFactory(self._localLearnEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetIR_setOnLearnHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onLearn, None)
		except RuntimeError:
			self._Learn = None
			self._onLearn = None

	def _localRawDataEvent(self, handle, userPtr, data, dataLen):
		if self._RawData == None:
			return
		data = [data[i] for i in range(dataLen)]
		self._RawData(self, data)

	def setOnRawDataHandler(self, handler):
		if handler == None:
			self._RawData = None
			self._onRawData = None
		else:
			self._RawData = handler
			self._onRawData = self._RawDataFactory(self._localRawDataEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetIR_setOnRawDataHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onRawData, None)
		except RuntimeError:
			self._RawData = None
			self._onRawData = None

	def getLastCode(self):
		_code = (ctypes.c_char * 33)()
		_codeLen = ctypes.c_int32(33)
		_bitCount = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetIR_getLastCode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_code), _codeLen, ctypes.byref(_bitCount))

		if result > 0:
			raise PhidgetException(result)

		return _code.value.decode('utf-8'), _bitCount.value

	def getLastLearnedCode(self):
		_code = (ctypes.c_char * 33)()
		_codeLen = ctypes.c_int32(33)
		_codeInfo = CodeInfo()

		__func = PhidgetSupport.getDll().PhidgetIR_getLastLearnedCode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_code), _codeLen, ctypes.byref(_codeInfo))

		if result > 0:
			raise PhidgetException(result)

		return _code.value.decode('utf-8'), _codeInfo.toPython()

	def transmit(self, code, codeInfo):
		_code = ctypes.create_string_buffer(code.encode('utf-8'))
		_codeInfo = codeInfo.fromPython()

		__func = PhidgetSupport.getDll().PhidgetIR_transmit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_code), ctypes.byref(_codeInfo))

		if result > 0:
			raise PhidgetException(result)


	def transmitRaw(self, data, carrierFrequency, dutyCycle, gap):
		_data = (ctypes.c_uint32 * len(data))(*data)
		_dataLen = ctypes.c_int32(len(data))
		_carrierFrequency = ctypes.c_uint32(carrierFrequency)
		_dutyCycle = ctypes.c_double(dutyCycle)
		_gap = ctypes.c_uint32(gap)

		__func = PhidgetSupport.getDll().PhidgetIR_transmitRaw
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_data), _dataLen, _carrierFrequency, _dutyCycle, _gap)

		if result > 0:
			raise PhidgetException(result)


	def transmitRepeat(self):
		__func = PhidgetSupport.getDll().PhidgetIR_transmitRepeat
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	RAW_DATA_LONG_SPACE = 4294967295

	IR_MAX_CODE_BIT_COUNT = 128

	IR_MAX_CODE_STR_LENGTH = 33



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport

class AsyncSupport:
	__callbacks = {}
	__nativecallback = None

	@staticmethod
	def add(entry, phid):
		t = (entry, phid);
		AsyncSupport.__callbacks[id(t)] = t
		return id(t)

	@staticmethod
	def __getAndRemove(id):
		entry = AsyncSupport.__callbacks.get(id)
		del AsyncSupport.__callbacks[id]
		return entry

	@staticmethod
	def __async_callback(handle, ctx, res):

		if ctx == None:
			return

		# look up callback
		entry = AsyncSupport.__getAndRemove(ctx)
		if entry == None:
			return

		_code = ctypes.c_int(res)
		_desc = ctypes.c_char_p()
		result = PhidgetSupport.getDll().Phidget_getErrorDescription(_code, ctypes.byref(_desc))
		details = _desc.value
		entry[0](entry[1], res, details)

	@staticmethod
	def getCallback():
		if AsyncSupport.__nativecallback is None:
			if sys.platform == 'win32':
				AsyncSupport.__nativecallback = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int)(AsyncSupport.__async_callback)
			else:
				AsyncSupport.__nativecallback = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int)(AsyncSupport.__async_callback)
		return AsyncSupport.__nativecallback


import sys
import ctypes
class IRCodeLength:
	# Unknown - the default value
	IR_LENGTH_UNKNOWN = 1
	# Constant - the bitstream and gap length is constant
	IR_LENGTH_CONSTANT = 2
	# Variable - the bitstream has a variable length with a constant gap
	IR_LENGTH_VARIABLE = 3

	@classmethod
	def getName(self, val):
		if val == self.IR_LENGTH_UNKNOWN:
			return "IR_LENGTH_UNKNOWN"
		if val == self.IR_LENGTH_CONSTANT:
			return "IR_LENGTH_CONSTANT"
		if val == self.IR_LENGTH_VARIABLE:
			return "IR_LENGTH_VARIABLE"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Accelerometer(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._AccelerationChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		else:
			self._AccelerationChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.POINTER(ctypes.c_double), ctypes.c_double)
		self._AccelerationChange = None
		self._onAccelerationChange = None

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localAccelerationChangeEvent(self, handle, userPtr, acceleration, timestamp):
		if self._AccelerationChange == None:
			return
		acceleration = [acceleration[i] for i in range(3)]
		self._AccelerationChange(self, acceleration, timestamp)

	def setOnAccelerationChangeHandler(self, handler):
		if handler == None:
			self._AccelerationChange = None
			self._onAccelerationChange = None
		else:
			self._AccelerationChange = handler
			self._onAccelerationChange = self._AccelerationChangeFactory(self._localAccelerationChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetAccelerometer_setOnAccelerationChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onAccelerationChange, None)
		except RuntimeError:
			self._AccelerationChange = None
			self._onAccelerationChange = None

	def getAcceleration(self):
		_Acceleration = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Acceleration))

		if result > 0:
			raise PhidgetException(result)

		return list(_Acceleration)

	def getMinAcceleration(self):
		_MinAcceleration = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getMinAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return list(_MinAcceleration)

	def getMaxAcceleration(self):
		_MaxAcceleration = (ctypes.c_double * 3)()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getMaxAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return list(_MaxAcceleration)

	def getAccelerationChangeTrigger(self):
		_AccelerationChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getAccelerationChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_AccelerationChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _AccelerationChangeTrigger.value

	def setAccelerationChangeTrigger(self, AccelerationChangeTrigger):
		_AccelerationChangeTrigger = ctypes.c_double(AccelerationChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_setAccelerationChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _AccelerationChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinAccelerationChangeTrigger(self):
		_MinAccelerationChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getMinAccelerationChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAccelerationChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinAccelerationChangeTrigger.value

	def getMaxAccelerationChangeTrigger(self):
		_MaxAccelerationChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getMaxAccelerationChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAccelerationChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxAccelerationChangeTrigger.value

	def getAxisCount(self):
		_AxisCount = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getAxisCount
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_AxisCount))

		if result > 0:
			raise PhidgetException(result)

		return _AxisCount.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getHeatingEnabled(self):
		_HeatingEnabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getHeatingEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HeatingEnabled))

		if result > 0:
			raise PhidgetException(result)

		return _HeatingEnabled.value

	def setHeatingEnabled(self, HeatingEnabled):
		_HeatingEnabled = ctypes.c_int(HeatingEnabled)

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_setHeatingEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _HeatingEnabled)

		if result > 0:
			raise PhidgetException(result)


	def getTimestamp(self):
		_Timestamp = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetAccelerometer_getTimestamp
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Timestamp))

		if result > 0:
			raise PhidgetException(result)

		return _Timestamp.value



import sys
import ctypes
class HubPortMode:
	# Communicate with a smart VINT device
	PORT_MODE_VINT_PORT = 0
	# 5V Logic-level digital input
	PORT_MODE_DIGITAL_INPUT = 1
	# 3.3V digital output
	PORT_MODE_DIGITAL_OUTPUT = 2
	# 0-5V voltage input for non-ratiometric sensors 
	PORT_MODE_VOLTAGE_INPUT = 3
	# 0-5V voltage input for ratiometric sensors
	PORT_MODE_VOLTAGE_RATIO_INPUT = 4

	@classmethod
	def getName(self, val):
		if val == self.PORT_MODE_VINT_PORT:
			return "PORT_MODE_VINT_PORT"
		if val == self.PORT_MODE_DIGITAL_INPUT:
			return "PORT_MODE_DIGITAL_INPUT"
		if val == self.PORT_MODE_DIGITAL_OUTPUT:
			return "PORT_MODE_DIGITAL_OUTPUT"
		if val == self.PORT_MODE_VOLTAGE_INPUT:
			return "PORT_MODE_VOLTAGE_INPUT"
		if val == self.PORT_MODE_VOLTAGE_RATIO_INPUT:
			return "PORT_MODE_VOLTAGE_RATIO_INPUT"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.StepperControlMode import StepperControlMode
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Stepper(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()
		self._setTargetPosition_async = None
		self._onsetTargetPosition_async = None

		if sys.platform == 'win32':
			self._PositionChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._PositionChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._PositionChange = None
		self._onPositionChange = None

		if sys.platform == 'win32':
			self._StoppedFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p)
		else:
			self._StoppedFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p)
		self._Stopped = None
		self._onStopped = None

		if sys.platform == 'win32':
			self._VelocityChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._VelocityChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._VelocityChange = None
		self._onVelocityChange = None

		__func = PhidgetSupport.getDll().PhidgetStepper_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localPositionChangeEvent(self, handle, userPtr, position):
		if self._PositionChange == None:
			return
		self._PositionChange(self, position)

	def setOnPositionChangeHandler(self, handler):
		if handler == None:
			self._PositionChange = None
			self._onPositionChange = None
		else:
			self._PositionChange = handler
			self._onPositionChange = self._PositionChangeFactory(self._localPositionChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetStepper_setOnPositionChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPositionChange, None)
		except RuntimeError:
			self._PositionChange = None
			self._onPositionChange = None

	def _localStoppedEvent(self, handle, userPtr):
		if self._Stopped == None:
			return
		self._Stopped(self)

	def setOnStoppedHandler(self, handler):
		if handler == None:
			self._Stopped = None
			self._onStopped = None
		else:
			self._Stopped = handler
			self._onStopped = self._StoppedFactory(self._localStoppedEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetStepper_setOnStoppedHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onStopped, None)
		except RuntimeError:
			self._Stopped = None
			self._onStopped = None

	def _localVelocityChangeEvent(self, handle, userPtr, velocity):
		if self._VelocityChange == None:
			return
		self._VelocityChange(self, velocity)

	def setOnVelocityChangeHandler(self, handler):
		if handler == None:
			self._VelocityChange = None
			self._onVelocityChange = None
		else:
			self._VelocityChange = handler
			self._onVelocityChange = self._VelocityChangeFactory(self._localVelocityChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetStepper_setOnVelocityChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onVelocityChange, None)
		except RuntimeError:
			self._VelocityChange = None
			self._onVelocityChange = None

	def getAcceleration(self):
		_Acceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Acceleration))

		if result > 0:
			raise PhidgetException(result)

		return _Acceleration.value

	def setAcceleration(self, Acceleration):
		_Acceleration = ctypes.c_double(Acceleration)

		__func = PhidgetSupport.getDll().PhidgetStepper_setAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Acceleration)

		if result > 0:
			raise PhidgetException(result)


	def getMinAcceleration(self):
		_MinAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMinAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MinAcceleration.value

	def getMaxAcceleration(self):
		_MaxAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMaxAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MaxAcceleration.value

	def getControlMode(self):
		_ControlMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetStepper_getControlMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ControlMode))

		if result > 0:
			raise PhidgetException(result)

		return _ControlMode.value

	def setControlMode(self, ControlMode):
		_ControlMode = ctypes.c_int(ControlMode)

		__func = PhidgetSupport.getDll().PhidgetStepper_setControlMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _ControlMode)

		if result > 0:
			raise PhidgetException(result)


	def getCurrentLimit(self):
		_CurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _CurrentLimit.value

	def setCurrentLimit(self, CurrentLimit):
		_CurrentLimit = ctypes.c_double(CurrentLimit)

		__func = PhidgetSupport.getDll().PhidgetStepper_setCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CurrentLimit)

		if result > 0:
			raise PhidgetException(result)


	def getMinCurrentLimit(self):
		_MinCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMinCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MinCurrentLimit.value

	def getMaxCurrentLimit(self):
		_MaxCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMaxCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MaxCurrentLimit.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetStepper_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetStepper_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetStepper_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getEngaged(self):
		_Engaged = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetStepper_getEngaged
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Engaged))

		if result > 0:
			raise PhidgetException(result)

		return _Engaged.value

	def setEngaged(self, Engaged):
		_Engaged = ctypes.c_int(Engaged)

		__func = PhidgetSupport.getDll().PhidgetStepper_setEngaged
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Engaged)

		if result > 0:
			raise PhidgetException(result)


	def enableFailsafe(self, failsafeTime):
		_failsafeTime = ctypes.c_uint32(failsafeTime)

		__func = PhidgetSupport.getDll().PhidgetStepper_enableFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _failsafeTime)

		if result > 0:
			raise PhidgetException(result)


	def getMinFailsafeTime(self):
		_MinFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMinFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MinFailsafeTime.value

	def getMaxFailsafeTime(self):
		_MaxFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMaxFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFailsafeTime.value

	def getHoldingCurrentLimit(self):
		_HoldingCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getHoldingCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HoldingCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _HoldingCurrentLimit.value

	def setHoldingCurrentLimit(self, HoldingCurrentLimit):
		_HoldingCurrentLimit = ctypes.c_double(HoldingCurrentLimit)

		__func = PhidgetSupport.getDll().PhidgetStepper_setHoldingCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _HoldingCurrentLimit)

		if result > 0:
			raise PhidgetException(result)


	def getIsMoving(self):
		_IsMoving = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetStepper_getIsMoving
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IsMoving))

		if result > 0:
			raise PhidgetException(result)

		return _IsMoving.value

	def getPosition(self):
		_Position = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Position))

		if result > 0:
			raise PhidgetException(result)

		return _Position.value

	def getMinPosition(self):
		_MinPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMinPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPosition))

		if result > 0:
			raise PhidgetException(result)

		return _MinPosition.value

	def getMaxPosition(self):
		_MaxPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMaxPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPosition))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPosition.value

	def addPositionOffset(self, positionOffset):
		_positionOffset = ctypes.c_double(positionOffset)

		__func = PhidgetSupport.getDll().PhidgetStepper_addPositionOffset
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _positionOffset)

		if result > 0:
			raise PhidgetException(result)


	def getRescaleFactor(self):
		_RescaleFactor = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getRescaleFactor
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_RescaleFactor))

		if result > 0:
			raise PhidgetException(result)

		return _RescaleFactor.value

	def setRescaleFactor(self, RescaleFactor):
		_RescaleFactor = ctypes.c_double(RescaleFactor)

		__func = PhidgetSupport.getDll().PhidgetStepper_setRescaleFactor
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _RescaleFactor)

		if result > 0:
			raise PhidgetException(result)


	def resetFailsafe(self):
		__func = PhidgetSupport.getDll().PhidgetStepper_resetFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getTargetPosition(self):
		_TargetPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getTargetPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TargetPosition))

		if result > 0:
			raise PhidgetException(result)

		return _TargetPosition.value

	def setTargetPosition(self, TargetPosition):
		_TargetPosition = ctypes.c_double(TargetPosition)

		__func = PhidgetSupport.getDll().PhidgetStepper_setTargetPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TargetPosition)

		if result > 0:
			raise PhidgetException(result)


	def setTargetPosition_async(self, TargetPosition, asyncHandler):
		_TargetPosition = ctypes.c_double(TargetPosition)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetStepper_setTargetPosition_async
		__func(self.handle, _TargetPosition, _asyncHandler, _ctx)


	def getVelocity(self):
		_Velocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Velocity))

		if result > 0:
			raise PhidgetException(result)

		return _Velocity.value

	def getVelocityLimit(self):
		_VelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _VelocityLimit.value

	def setVelocityLimit(self, VelocityLimit):
		_VelocityLimit = ctypes.c_double(VelocityLimit)

		__func = PhidgetSupport.getDll().PhidgetStepper_setVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _VelocityLimit)

		if result > 0:
			raise PhidgetException(result)


	def getMinVelocityLimit(self):
		_MinVelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMinVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MinVelocityLimit.value

	def getMaxVelocityLimit(self):
		_MaxVelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetStepper_getMaxVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVelocityLimit.value



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.RCServoVoltage import RCServoVoltage
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class RCServo(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()
		self._setTargetPosition_async = None
		self._onsetTargetPosition_async = None

		if sys.platform == 'win32':
			self._PositionChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._PositionChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._PositionChange = None
		self._onPositionChange = None

		if sys.platform == 'win32':
			self._TargetPositionReachedFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._TargetPositionReachedFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._TargetPositionReached = None
		self._onTargetPositionReached = None

		if sys.platform == 'win32':
			self._VelocityChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._VelocityChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._VelocityChange = None
		self._onVelocityChange = None

		__func = PhidgetSupport.getDll().PhidgetRCServo_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localPositionChangeEvent(self, handle, userPtr, position):
		if self._PositionChange == None:
			return
		self._PositionChange(self, position)

	def setOnPositionChangeHandler(self, handler):
		if handler == None:
			self._PositionChange = None
			self._onPositionChange = None
		else:
			self._PositionChange = handler
			self._onPositionChange = self._PositionChangeFactory(self._localPositionChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetRCServo_setOnPositionChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPositionChange, None)
		except RuntimeError:
			self._PositionChange = None
			self._onPositionChange = None

	def _localTargetPositionReachedEvent(self, handle, userPtr, position):
		if self._TargetPositionReached == None:
			return
		self._TargetPositionReached(self, position)

	def setOnTargetPositionReachedHandler(self, handler):
		if handler == None:
			self._TargetPositionReached = None
			self._onTargetPositionReached = None
		else:
			self._TargetPositionReached = handler
			self._onTargetPositionReached = self._TargetPositionReachedFactory(self._localTargetPositionReachedEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetRCServo_setOnTargetPositionReachedHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onTargetPositionReached, None)
		except RuntimeError:
			self._TargetPositionReached = None
			self._onTargetPositionReached = None

	def _localVelocityChangeEvent(self, handle, userPtr, velocity):
		if self._VelocityChange == None:
			return
		self._VelocityChange(self, velocity)

	def setOnVelocityChangeHandler(self, handler):
		if handler == None:
			self._VelocityChange = None
			self._onVelocityChange = None
		else:
			self._VelocityChange = handler
			self._onVelocityChange = self._VelocityChangeFactory(self._localVelocityChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetRCServo_setOnVelocityChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onVelocityChange, None)
		except RuntimeError:
			self._VelocityChange = None
			self._onVelocityChange = None

	def getAcceleration(self):
		_Acceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Acceleration))

		if result > 0:
			raise PhidgetException(result)

		return _Acceleration.value

	def setAcceleration(self, Acceleration):
		_Acceleration = ctypes.c_double(Acceleration)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Acceleration)

		if result > 0:
			raise PhidgetException(result)


	def getMinAcceleration(self):
		_MinAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MinAcceleration.value

	def getMaxAcceleration(self):
		_MaxAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MaxAcceleration.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getEngaged(self):
		_Engaged = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getEngaged
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Engaged))

		if result > 0:
			raise PhidgetException(result)

		return _Engaged.value

	def setEngaged(self, Engaged):
		_Engaged = ctypes.c_int(Engaged)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setEngaged
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Engaged)

		if result > 0:
			raise PhidgetException(result)


	def enableFailsafe(self, failsafeTime):
		_failsafeTime = ctypes.c_uint32(failsafeTime)

		__func = PhidgetSupport.getDll().PhidgetRCServo_enableFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _failsafeTime)

		if result > 0:
			raise PhidgetException(result)


	def getMinFailsafeTime(self):
		_MinFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MinFailsafeTime.value

	def getMaxFailsafeTime(self):
		_MaxFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFailsafeTime.value

	def getIsMoving(self):
		_IsMoving = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getIsMoving
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IsMoving))

		if result > 0:
			raise PhidgetException(result)

		return _IsMoving.value

	def getPosition(self):
		_Position = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Position))

		if result > 0:
			raise PhidgetException(result)

		return _Position.value

	def setMinPosition(self, MinPosition):
		_MinPosition = ctypes.c_double(MinPosition)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setMinPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _MinPosition)

		if result > 0:
			raise PhidgetException(result)


	def getMinPosition(self):
		_MinPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPosition))

		if result > 0:
			raise PhidgetException(result)

		return _MinPosition.value

	def setMaxPosition(self, MaxPosition):
		_MaxPosition = ctypes.c_double(MaxPosition)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setMaxPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _MaxPosition)

		if result > 0:
			raise PhidgetException(result)


	def getMaxPosition(self):
		_MaxPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPosition))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPosition.value

	def setMinPulseWidth(self, MinPulseWidth):
		_MinPulseWidth = ctypes.c_double(MinPulseWidth)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setMinPulseWidth
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _MinPulseWidth)

		if result > 0:
			raise PhidgetException(result)


	def getMinPulseWidth(self):
		_MinPulseWidth = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinPulseWidth
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPulseWidth))

		if result > 0:
			raise PhidgetException(result)

		return _MinPulseWidth.value

	def setMaxPulseWidth(self, MaxPulseWidth):
		_MaxPulseWidth = ctypes.c_double(MaxPulseWidth)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setMaxPulseWidth
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _MaxPulseWidth)

		if result > 0:
			raise PhidgetException(result)


	def getMaxPulseWidth(self):
		_MaxPulseWidth = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxPulseWidth
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPulseWidth))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPulseWidth.value

	def getMinPulseWidthLimit(self):
		_MinPulseWidthLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinPulseWidthLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPulseWidthLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MinPulseWidthLimit.value

	def getMaxPulseWidthLimit(self):
		_MaxPulseWidthLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxPulseWidthLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPulseWidthLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPulseWidthLimit.value

	def resetFailsafe(self):
		__func = PhidgetSupport.getDll().PhidgetRCServo_resetFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getSpeedRampingState(self):
		_SpeedRampingState = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getSpeedRampingState
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_SpeedRampingState))

		if result > 0:
			raise PhidgetException(result)

		return _SpeedRampingState.value

	def setSpeedRampingState(self, SpeedRampingState):
		_SpeedRampingState = ctypes.c_int(SpeedRampingState)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setSpeedRampingState
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _SpeedRampingState)

		if result > 0:
			raise PhidgetException(result)


	def getTargetPosition(self):
		_TargetPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getTargetPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TargetPosition))

		if result > 0:
			raise PhidgetException(result)

		return _TargetPosition.value

	def setTargetPosition(self, TargetPosition):
		_TargetPosition = ctypes.c_double(TargetPosition)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setTargetPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TargetPosition)

		if result > 0:
			raise PhidgetException(result)


	def setTargetPosition_async(self, TargetPosition, asyncHandler):
		_TargetPosition = ctypes.c_double(TargetPosition)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetRCServo_setTargetPosition_async
		__func(self.handle, _TargetPosition, _asyncHandler, _ctx)


	def getTorque(self):
		_Torque = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getTorque
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Torque))

		if result > 0:
			raise PhidgetException(result)

		return _Torque.value

	def setTorque(self, Torque):
		_Torque = ctypes.c_double(Torque)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setTorque
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Torque)

		if result > 0:
			raise PhidgetException(result)


	def getMinTorque(self):
		_MinTorque = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinTorque
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinTorque))

		if result > 0:
			raise PhidgetException(result)

		return _MinTorque.value

	def getMaxTorque(self):
		_MaxTorque = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxTorque
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxTorque))

		if result > 0:
			raise PhidgetException(result)

		return _MaxTorque.value

	def getVelocity(self):
		_Velocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Velocity))

		if result > 0:
			raise PhidgetException(result)

		return _Velocity.value

	def getVelocityLimit(self):
		_VelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _VelocityLimit.value

	def setVelocityLimit(self, VelocityLimit):
		_VelocityLimit = ctypes.c_double(VelocityLimit)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _VelocityLimit)

		if result > 0:
			raise PhidgetException(result)


	def getMinVelocityLimit(self):
		_MinVelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMinVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MinVelocityLimit.value

	def getMaxVelocityLimit(self):
		_MaxVelocityLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getMaxVelocityLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVelocityLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVelocityLimit.value

	def getVoltage(self):
		_Voltage = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetRCServo_getVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Voltage))

		if result > 0:
			raise PhidgetException(result)

		return _Voltage.value

	def setVoltage(self, Voltage):
		_Voltage = ctypes.c_int(Voltage)

		__func = PhidgetSupport.getDll().PhidgetRCServo_setVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Voltage)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
class SPLRange:
	# Range 102dB
	SPL_RANGE_102dB = 1
	# Range 82dB
	SPL_RANGE_82dB = 2

	@classmethod
	def getName(self, val):
		if val == self.SPL_RANGE_102dB:
			return "SPL_RANGE_102dB"
		if val == self.SPL_RANGE_82dB:
			return "SPL_RANGE_82dB"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PowerSupply import PowerSupply
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class CurrentInput(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._CurrentChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._CurrentChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._CurrentChange = None
		self._onCurrentChange = None

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localCurrentChangeEvent(self, handle, userPtr, current):
		if self._CurrentChange == None:
			return
		self._CurrentChange(self, current)

	def setOnCurrentChangeHandler(self, handler):
		if handler == None:
			self._CurrentChange = None
			self._onCurrentChange = None
		else:
			self._CurrentChange = handler
			self._onCurrentChange = self._CurrentChangeFactory(self._localCurrentChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetCurrentInput_setOnCurrentChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onCurrentChange, None)
		except RuntimeError:
			self._CurrentChange = None
			self._onCurrentChange = None

	def getCurrent(self):
		_Current = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getCurrent
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Current))

		if result > 0:
			raise PhidgetException(result)

		return _Current.value

	def getMinCurrent(self):
		_MinCurrent = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getMinCurrent
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinCurrent))

		if result > 0:
			raise PhidgetException(result)

		return _MinCurrent.value

	def getMaxCurrent(self):
		_MaxCurrent = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getMaxCurrent
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxCurrent))

		if result > 0:
			raise PhidgetException(result)

		return _MaxCurrent.value

	def getCurrentChangeTrigger(self):
		_CurrentChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getCurrentChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CurrentChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _CurrentChangeTrigger.value

	def setCurrentChangeTrigger(self, CurrentChangeTrigger):
		_CurrentChangeTrigger = ctypes.c_double(CurrentChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_setCurrentChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CurrentChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinCurrentChangeTrigger(self):
		_MinCurrentChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getMinCurrentChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinCurrentChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinCurrentChangeTrigger.value

	def getMaxCurrentChangeTrigger(self):
		_MaxCurrentChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getMaxCurrentChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxCurrentChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxCurrentChangeTrigger.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getPowerSupply(self):
		_PowerSupply = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_getPowerSupply
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PowerSupply))

		if result > 0:
			raise PhidgetException(result)

		return _PowerSupply.value

	def setPowerSupply(self, PowerSupply):
		_PowerSupply = ctypes.c_int(PowerSupply)

		__func = PhidgetSupport.getDll().PhidgetCurrentInput_setPowerSupply
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _PowerSupply)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class BLDCMotor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()
		self._setTargetVelocity_async = None
		self._onsetTargetVelocity_async = None

		if sys.platform == 'win32':
			self._BrakingStrengthChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._BrakingStrengthChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._BrakingStrengthChange = None
		self._onBrakingStrengthChange = None

		if sys.platform == 'win32':
			self._PositionChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._PositionChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._PositionChange = None
		self._onPositionChange = None

		if sys.platform == 'win32':
			self._VelocityUpdateFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._VelocityUpdateFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._VelocityUpdate = None
		self._onVelocityUpdate = None

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localBrakingStrengthChangeEvent(self, handle, userPtr, brakingStrength):
		if self._BrakingStrengthChange == None:
			return
		self._BrakingStrengthChange(self, brakingStrength)

	def setOnBrakingStrengthChangeHandler(self, handler):
		if handler == None:
			self._BrakingStrengthChange = None
			self._onBrakingStrengthChange = None
		else:
			self._BrakingStrengthChange = handler
			self._onBrakingStrengthChange = self._BrakingStrengthChangeFactory(self._localBrakingStrengthChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setOnBrakingStrengthChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onBrakingStrengthChange, None)
		except RuntimeError:
			self._BrakingStrengthChange = None
			self._onBrakingStrengthChange = None

	def _localPositionChangeEvent(self, handle, userPtr, position):
		if self._PositionChange == None:
			return
		self._PositionChange(self, position)

	def setOnPositionChangeHandler(self, handler):
		if handler == None:
			self._PositionChange = None
			self._onPositionChange = None
		else:
			self._PositionChange = handler
			self._onPositionChange = self._PositionChangeFactory(self._localPositionChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setOnPositionChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPositionChange, None)
		except RuntimeError:
			self._PositionChange = None
			self._onPositionChange = None

	def _localVelocityUpdateEvent(self, handle, userPtr, velocity):
		if self._VelocityUpdate == None:
			return
		self._VelocityUpdate(self, velocity)

	def setOnVelocityUpdateHandler(self, handler):
		if handler == None:
			self._VelocityUpdate = None
			self._onVelocityUpdate = None
		else:
			self._VelocityUpdate = handler
			self._onVelocityUpdate = self._VelocityUpdateFactory(self._localVelocityUpdateEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setOnVelocityUpdateHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onVelocityUpdate, None)
		except RuntimeError:
			self._VelocityUpdate = None
			self._onVelocityUpdate = None

	def getAcceleration(self):
		_Acceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Acceleration))

		if result > 0:
			raise PhidgetException(result)

		return _Acceleration.value

	def setAcceleration(self, Acceleration):
		_Acceleration = ctypes.c_double(Acceleration)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Acceleration)

		if result > 0:
			raise PhidgetException(result)


	def getMinAcceleration(self):
		_MinAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMinAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MinAcceleration.value

	def getMaxAcceleration(self):
		_MaxAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMaxAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MaxAcceleration.value

	def getBrakingStrength(self):
		_BrakingStrength = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_BrakingStrength))

		if result > 0:
			raise PhidgetException(result)

		return _BrakingStrength.value

	def getMinBrakingStrength(self):
		_MinBrakingStrength = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMinBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinBrakingStrength))

		if result > 0:
			raise PhidgetException(result)

		return _MinBrakingStrength.value

	def getMaxBrakingStrength(self):
		_MaxBrakingStrength = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMaxBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxBrakingStrength))

		if result > 0:
			raise PhidgetException(result)

		return _MaxBrakingStrength.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def enableFailsafe(self, failsafeTime):
		_failsafeTime = ctypes.c_uint32(failsafeTime)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_enableFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _failsafeTime)

		if result > 0:
			raise PhidgetException(result)


	def getMinFailsafeTime(self):
		_MinFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMinFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MinFailsafeTime.value

	def getMaxFailsafeTime(self):
		_MaxFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMaxFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFailsafeTime.value

	def getPosition(self):
		_Position = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Position))

		if result > 0:
			raise PhidgetException(result)

		return _Position.value

	def getMinPosition(self):
		_MinPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMinPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPosition))

		if result > 0:
			raise PhidgetException(result)

		return _MinPosition.value

	def getMaxPosition(self):
		_MaxPosition = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMaxPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPosition))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPosition.value

	def addPositionOffset(self, positionOffset):
		_positionOffset = ctypes.c_double(positionOffset)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_addPositionOffset
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _positionOffset)

		if result > 0:
			raise PhidgetException(result)


	def getRescaleFactor(self):
		_RescaleFactor = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getRescaleFactor
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_RescaleFactor))

		if result > 0:
			raise PhidgetException(result)

		return _RescaleFactor.value

	def setRescaleFactor(self, RescaleFactor):
		_RescaleFactor = ctypes.c_double(RescaleFactor)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setRescaleFactor
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _RescaleFactor)

		if result > 0:
			raise PhidgetException(result)


	def resetFailsafe(self):
		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_resetFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getStallVelocity(self):
		_StallVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getStallVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_StallVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _StallVelocity.value

	def setStallVelocity(self, StallVelocity):
		_StallVelocity = ctypes.c_double(StallVelocity)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setStallVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _StallVelocity)

		if result > 0:
			raise PhidgetException(result)


	def getMinStallVelocity(self):
		_MinStallVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMinStallVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinStallVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _MinStallVelocity.value

	def getMaxStallVelocity(self):
		_MaxStallVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMaxStallVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxStallVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _MaxStallVelocity.value

	def getTargetBrakingStrength(self):
		_TargetBrakingStrength = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getTargetBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TargetBrakingStrength))

		if result > 0:
			raise PhidgetException(result)

		return _TargetBrakingStrength.value

	def setTargetBrakingStrength(self, TargetBrakingStrength):
		_TargetBrakingStrength = ctypes.c_double(TargetBrakingStrength)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setTargetBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TargetBrakingStrength)

		if result > 0:
			raise PhidgetException(result)


	def getTargetVelocity(self):
		_TargetVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getTargetVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TargetVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _TargetVelocity.value

	def setTargetVelocity(self, TargetVelocity):
		_TargetVelocity = ctypes.c_double(TargetVelocity)

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setTargetVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TargetVelocity)

		if result > 0:
			raise PhidgetException(result)


	def setTargetVelocity_async(self, TargetVelocity, asyncHandler):
		_TargetVelocity = ctypes.c_double(TargetVelocity)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_setTargetVelocity_async
		__func(self.handle, _TargetVelocity, _asyncHandler, _ctx)


	def getVelocity(self):
		_Velocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Velocity))

		if result > 0:
			raise PhidgetException(result)

		return _Velocity.value

	def getMinVelocity(self):
		_MinVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMinVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _MinVelocity.value

	def getMaxVelocity(self):
		_MaxVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetBLDCMotor_getMaxVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVelocity.value



import sys
import ctypes
class PacketErrorCode:
	# No error
	PACKET_ERROR_OK = 0
	# Unknown Error
	PACKET_ERROR_UNKNOWN = 1
	# The response packet timed out
	PACKET_ERROR_TIMEOUT = 2
	# Something about the received transmission didn't match the expected format.
	PACKET_ERROR_FORMAT = 3
	# The input lines are invalid. This likely means a cable has been unplugged.
	PACKET_ERROR_INVALID = 4
	# Data is being received fater than it can be processed. Some has been lost.
	PACKET_ERROR_OVERRUN = 5
	# Something behind the scenes got out of sequence.
	PACKET_ERROR_CORRUPT = 6

	@classmethod
	def getName(self, val):
		if val == self.PACKET_ERROR_OK:
			return "PACKET_ERROR_OK"
		if val == self.PACKET_ERROR_UNKNOWN:
			return "PACKET_ERROR_UNKNOWN"
		if val == self.PACKET_ERROR_TIMEOUT:
			return "PACKET_ERROR_TIMEOUT"
		if val == self.PACKET_ERROR_FORMAT:
			return "PACKET_ERROR_FORMAT"
		if val == self.PACKET_ERROR_INVALID:
			return "PACKET_ERROR_INVALID"
		if val == self.PACKET_ERROR_OVERRUN:
			return "PACKET_ERROR_OVERRUN"
		if val == self.PACKET_ERROR_CORRUPT:
			return "PACKET_ERROR_CORRUPT"
		return "<invalid enumeration value>"



import sys
import ctypes
class Encoding:
	# Unknown - the default value
	IR_ENCODING_UNKNOWN = 1
	# Space encoding, or Pulse Distance Modulation
	IR_ENCODING_SPACE = 2
	# Pulse encoding, or Pulse Width Modulation
	IR_ENCODING_PULSE = 3
	# Bi-Phase, or Manchester encoding
	IR_ENCODING_BIPHASE = 4
	# RC5 - a type of Bi-Phase encoding
	IR_ENCODING_RC5 = 5
	# RC6 - a type of Bi-Phase encoding
	IR_ENCODING_RC6 = 6

	@classmethod
	def getName(self, val):
		if val == self.IR_ENCODING_UNKNOWN:
			return "IR_ENCODING_UNKNOWN"
		if val == self.IR_ENCODING_SPACE:
			return "IR_ENCODING_SPACE"
		if val == self.IR_ENCODING_PULSE:
			return "IR_ENCODING_PULSE"
		if val == self.IR_ENCODING_BIPHASE:
			return "IR_ENCODING_BIPHASE"
		if val == self.IR_ENCODING_RC5:
			return "IR_ENCODING_RC5"
		if val == self.IR_ENCODING_RC6:
			return "IR_ENCODING_RC6"
		return "<invalid enumeration value>"



import sys
import ctypes
class VoltageRange:
	# Range ±10mV DC
	VOLTAGE_RANGE_10mV = 1
	# Range ±40mV DC
	VOLTAGE_RANGE_40mV = 2
	# Range ±200mV DC
	VOLTAGE_RANGE_200mV = 3
	# Range ±312.5mV DC
	VOLTAGE_RANGE_312_5mV = 4
	# Range ±400mV DC
	VOLTAGE_RANGE_400mV = 5
	# Range ±1000mV DC
	VOLTAGE_RANGE_1000mV = 6
	# Range ±2V DC
	VOLTAGE_RANGE_2V = 7
	# Range ±5V DC
	VOLTAGE_RANGE_5V = 8
	# Range ±15V DC
	VOLTAGE_RANGE_15V = 9
	# Range ±40V DC
	VOLTAGE_RANGE_40V = 10
	# Auto-range mode changes based on the present voltage measurements.
	VOLTAGE_RANGE_AUTO = 11

	@classmethod
	def getName(self, val):
		if val == self.VOLTAGE_RANGE_10mV:
			return "VOLTAGE_RANGE_10mV"
		if val == self.VOLTAGE_RANGE_40mV:
			return "VOLTAGE_RANGE_40mV"
		if val == self.VOLTAGE_RANGE_200mV:
			return "VOLTAGE_RANGE_200mV"
		if val == self.VOLTAGE_RANGE_312_5mV:
			return "VOLTAGE_RANGE_312_5mV"
		if val == self.VOLTAGE_RANGE_400mV:
			return "VOLTAGE_RANGE_400mV"
		if val == self.VOLTAGE_RANGE_1000mV:
			return "VOLTAGE_RANGE_1000mV"
		if val == self.VOLTAGE_RANGE_2V:
			return "VOLTAGE_RANGE_2V"
		if val == self.VOLTAGE_RANGE_5V:
			return "VOLTAGE_RANGE_5V"
		if val == self.VOLTAGE_RANGE_15V:
			return "VOLTAGE_RANGE_15V"
		if val == self.VOLTAGE_RANGE_40V:
			return "VOLTAGE_RANGE_40V"
		if val == self.VOLTAGE_RANGE_AUTO:
			return "VOLTAGE_RANGE_AUTO"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.InputMode import InputMode
from Phidget22.PowerSupply import PowerSupply
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class DigitalInput(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._StateChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int)
		else:
			self._StateChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int)
		self._StateChange = None
		self._onStateChange = None

		__func = PhidgetSupport.getDll().PhidgetDigitalInput_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localStateChangeEvent(self, handle, userPtr, state):
		if self._StateChange == None:
			return
		self._StateChange(self, state)

	def setOnStateChangeHandler(self, handler):
		if handler == None:
			self._StateChange = None
			self._onStateChange = None
		else:
			self._StateChange = handler
			self._onStateChange = self._StateChangeFactory(self._localStateChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDigitalInput_setOnStateChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onStateChange, None)
		except RuntimeError:
			self._StateChange = None
			self._onStateChange = None

	def getInputMode(self):
		_InputMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetDigitalInput_getInputMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_InputMode))

		if result > 0:
			raise PhidgetException(result)

		return _InputMode.value

	def setInputMode(self, InputMode):
		_InputMode = ctypes.c_int(InputMode)

		__func = PhidgetSupport.getDll().PhidgetDigitalInput_setInputMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _InputMode)

		if result > 0:
			raise PhidgetException(result)


	def getPowerSupply(self):
		_PowerSupply = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetDigitalInput_getPowerSupply
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PowerSupply))

		if result > 0:
			raise PhidgetException(result)

		return _PowerSupply.value

	def setPowerSupply(self, PowerSupply):
		_PowerSupply = ctypes.c_int(PowerSupply)

		__func = PhidgetSupport.getDll().PhidgetDigitalInput_setPowerSupply
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _PowerSupply)

		if result > 0:
			raise PhidgetException(result)


	def getState(self):
		_State = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetDigitalInput_getState
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_State))

		if result > 0:
			raise PhidgetException(result)

		return _State.value



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.LCDFont import LCDFont
from Phidget22.LCDPixelState import LCDPixelState
from Phidget22.LCDScreenSize import LCDScreenSize
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class LCD(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()
		self._setCharacterBitmap_async = None
		self._onsetCharacterBitmap_async = None
		self._clear_async = None
		self._onclear_async = None
		self._copy_async = None
		self._oncopy_async = None
		self._drawLine_async = None
		self._ondrawLine_async = None
		self._drawPixel_async = None
		self._ondrawPixel_async = None
		self._drawRect_async = None
		self._ondrawRect_async = None
		self._flush_async = None
		self._onflush_async = None
		self._setFrameBuffer_async = None
		self._onsetFrameBuffer_async = None
		self._saveFrameBuffer_async = None
		self._onsaveFrameBuffer_async = None
		self._writeBitmap_async = None
		self._onwriteBitmap_async = None
		self._writeText_async = None
		self._onwriteText_async = None

		__func = PhidgetSupport.getDll().PhidgetLCD_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def getBacklight(self):
		_Backlight = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLCD_getBacklight
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Backlight))

		if result > 0:
			raise PhidgetException(result)

		return _Backlight.value

	def setBacklight(self, Backlight):
		_Backlight = ctypes.c_double(Backlight)

		__func = PhidgetSupport.getDll().PhidgetLCD_setBacklight
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Backlight)

		if result > 0:
			raise PhidgetException(result)


	def getMinBacklight(self):
		_MinBacklight = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLCD_getMinBacklight
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinBacklight))

		if result > 0:
			raise PhidgetException(result)

		return _MinBacklight.value

	def getMaxBacklight(self):
		_MaxBacklight = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLCD_getMaxBacklight
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxBacklight))

		if result > 0:
			raise PhidgetException(result)

		return _MaxBacklight.value

	def setCharacterBitmap(self, font, character, bitmap):
		_font = ctypes.c_int(font)
		_character = ctypes.create_string_buffer(character.encode('utf-8'))
		_bitmap = (ctypes.c_uint8 * len(bitmap))(*bitmap)

		__func = PhidgetSupport.getDll().PhidgetLCD_setCharacterBitmap
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _font, ctypes.byref(_character), ctypes.byref(_bitmap))

		if result > 0:
			raise PhidgetException(result)


	def setCharacterBitmap_async(self, font, character, bitmap, asyncHandler):
		_font = ctypes.c_int(font)
		_character = ctypes.create_string_buffer(character.encode('utf-8'))
		_bitmap = (ctypes.c_uint8 * len(bitmap))(*bitmap)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_setCharacterBitmap_async
		__func(self.handle, _font, ctypes.byref(_character), ctypes.byref(_bitmap), _asyncHandler, _ctx)


	def getMaxCharacters(self, font):
		_font = ctypes.c_int(font)
		_maxCharacters = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getMaxCharacters
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _font, ctypes.byref(_maxCharacters))

		if result > 0:
			raise PhidgetException(result)

		return _maxCharacters.value

	def clear(self):
		__func = PhidgetSupport.getDll().PhidgetLCD_clear
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def clear_async(self, asyncHandler):

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_clear_async
		__func(self.handle, _asyncHandler, _ctx)


	def getContrast(self):
		_Contrast = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLCD_getContrast
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Contrast))

		if result > 0:
			raise PhidgetException(result)

		return _Contrast.value

	def setContrast(self, Contrast):
		_Contrast = ctypes.c_double(Contrast)

		__func = PhidgetSupport.getDll().PhidgetLCD_setContrast
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Contrast)

		if result > 0:
			raise PhidgetException(result)


	def getMinContrast(self):
		_MinContrast = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLCD_getMinContrast
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinContrast))

		if result > 0:
			raise PhidgetException(result)

		return _MinContrast.value

	def getMaxContrast(self):
		_MaxContrast = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetLCD_getMaxContrast
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxContrast))

		if result > 0:
			raise PhidgetException(result)

		return _MaxContrast.value

	def copy(self, sourceFramebuffer, destFramebuffer, sourceX1, sourceY1, sourceX2, sourceY2, destX, destY, inverted):
		_sourceFramebuffer = ctypes.c_int(sourceFramebuffer)
		_destFramebuffer = ctypes.c_int(destFramebuffer)
		_sourceX1 = ctypes.c_int(sourceX1)
		_sourceY1 = ctypes.c_int(sourceY1)
		_sourceX2 = ctypes.c_int(sourceX2)
		_sourceY2 = ctypes.c_int(sourceY2)
		_destX = ctypes.c_int(destX)
		_destY = ctypes.c_int(destY)
		_inverted = ctypes.c_int(inverted)

		__func = PhidgetSupport.getDll().PhidgetLCD_copy
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _sourceFramebuffer, _destFramebuffer, _sourceX1, _sourceY1, _sourceX2, _sourceY2, _destX, _destY, _inverted)

		if result > 0:
			raise PhidgetException(result)


	def copy_async(self, sourceFramebuffer, destFramebuffer, sourceX1, sourceY1, sourceX2, sourceY2, destX, destY, inverted, asyncHandler):
		_sourceFramebuffer = ctypes.c_int(sourceFramebuffer)
		_destFramebuffer = ctypes.c_int(destFramebuffer)
		_sourceX1 = ctypes.c_int(sourceX1)
		_sourceY1 = ctypes.c_int(sourceY1)
		_sourceX2 = ctypes.c_int(sourceX2)
		_sourceY2 = ctypes.c_int(sourceY2)
		_destX = ctypes.c_int(destX)
		_destY = ctypes.c_int(destY)
		_inverted = ctypes.c_int(inverted)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_copy_async
		__func(self.handle, _sourceFramebuffer, _destFramebuffer, _sourceX1, _sourceY1, _sourceX2, _sourceY2, _destX, _destY, _inverted, _asyncHandler, _ctx)


	def getCursorBlink(self):
		_CursorBlink = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getCursorBlink
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CursorBlink))

		if result > 0:
			raise PhidgetException(result)

		return _CursorBlink.value

	def setCursorBlink(self, CursorBlink):
		_CursorBlink = ctypes.c_int(CursorBlink)

		__func = PhidgetSupport.getDll().PhidgetLCD_setCursorBlink
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CursorBlink)

		if result > 0:
			raise PhidgetException(result)


	def getCursorOn(self):
		_CursorOn = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getCursorOn
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CursorOn))

		if result > 0:
			raise PhidgetException(result)

		return _CursorOn.value

	def setCursorOn(self, CursorOn):
		_CursorOn = ctypes.c_int(CursorOn)

		__func = PhidgetSupport.getDll().PhidgetLCD_setCursorOn
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CursorOn)

		if result > 0:
			raise PhidgetException(result)


	def drawLine(self, x1, y1, x2, y2):
		_x1 = ctypes.c_int(x1)
		_y1 = ctypes.c_int(y1)
		_x2 = ctypes.c_int(x2)
		_y2 = ctypes.c_int(y2)

		__func = PhidgetSupport.getDll().PhidgetLCD_drawLine
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _x1, _y1, _x2, _y2)

		if result > 0:
			raise PhidgetException(result)


	def drawLine_async(self, x1, y1, x2, y2, asyncHandler):
		_x1 = ctypes.c_int(x1)
		_y1 = ctypes.c_int(y1)
		_x2 = ctypes.c_int(x2)
		_y2 = ctypes.c_int(y2)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_drawLine_async
		__func(self.handle, _x1, _y1, _x2, _y2, _asyncHandler, _ctx)


	def drawPixel(self, x, y, pixelState):
		_x = ctypes.c_int(x)
		_y = ctypes.c_int(y)
		_pixelState = ctypes.c_int(pixelState)

		__func = PhidgetSupport.getDll().PhidgetLCD_drawPixel
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _x, _y, _pixelState)

		if result > 0:
			raise PhidgetException(result)


	def drawPixel_async(self, x, y, pixelState, asyncHandler):
		_x = ctypes.c_int(x)
		_y = ctypes.c_int(y)
		_pixelState = ctypes.c_int(pixelState)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_drawPixel_async
		__func(self.handle, _x, _y, _pixelState, _asyncHandler, _ctx)


	def drawRect(self, x1, y1, x2, y2, filled, inverted):
		_x1 = ctypes.c_int(x1)
		_y1 = ctypes.c_int(y1)
		_x2 = ctypes.c_int(x2)
		_y2 = ctypes.c_int(y2)
		_filled = ctypes.c_int(filled)
		_inverted = ctypes.c_int(inverted)

		__func = PhidgetSupport.getDll().PhidgetLCD_drawRect
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _x1, _y1, _x2, _y2, _filled, _inverted)

		if result > 0:
			raise PhidgetException(result)


	def drawRect_async(self, x1, y1, x2, y2, filled, inverted, asyncHandler):
		_x1 = ctypes.c_int(x1)
		_y1 = ctypes.c_int(y1)
		_x2 = ctypes.c_int(x2)
		_y2 = ctypes.c_int(y2)
		_filled = ctypes.c_int(filled)
		_inverted = ctypes.c_int(inverted)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_drawRect_async
		__func(self.handle, _x1, _y1, _x2, _y2, _filled, _inverted, _asyncHandler, _ctx)


	def flush(self):
		__func = PhidgetSupport.getDll().PhidgetLCD_flush
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def flush_async(self, asyncHandler):

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_flush_async
		__func(self.handle, _asyncHandler, _ctx)


	def getFontSize(self, font):
		_font = ctypes.c_int(font)
		_width = ctypes.c_int()
		_height = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getFontSize
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _font, ctypes.byref(_width), ctypes.byref(_height))

		if result > 0:
			raise PhidgetException(result)

		return _width.value, _height.value

	def setFontSize(self, font, width, height):
		_font = ctypes.c_int(font)
		_width = ctypes.c_int(width)
		_height = ctypes.c_int(height)

		__func = PhidgetSupport.getDll().PhidgetLCD_setFontSize
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _font, _width, _height)

		if result > 0:
			raise PhidgetException(result)


	def getFrameBuffer(self):
		_FrameBuffer = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getFrameBuffer
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_FrameBuffer))

		if result > 0:
			raise PhidgetException(result)

		return _FrameBuffer.value

	def setFrameBuffer(self, FrameBuffer):
		_FrameBuffer = ctypes.c_int(FrameBuffer)

		__func = PhidgetSupport.getDll().PhidgetLCD_setFrameBuffer
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _FrameBuffer)

		if result > 0:
			raise PhidgetException(result)


	def setFrameBuffer_async(self, FrameBuffer, asyncHandler):
		_FrameBuffer = ctypes.c_int(FrameBuffer)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_setFrameBuffer_async
		__func(self.handle, _FrameBuffer, _asyncHandler, _ctx)


	def getHeight(self):
		_Height = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getHeight
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Height))

		if result > 0:
			raise PhidgetException(result)

		return _Height.value

	def initialize(self):
		__func = PhidgetSupport.getDll().PhidgetLCD_initialize
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def saveFrameBuffer(self, frameBuffer):
		_frameBuffer = ctypes.c_int(frameBuffer)

		__func = PhidgetSupport.getDll().PhidgetLCD_saveFrameBuffer
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _frameBuffer)

		if result > 0:
			raise PhidgetException(result)


	def saveFrameBuffer_async(self, frameBuffer, asyncHandler):
		_frameBuffer = ctypes.c_int(frameBuffer)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_saveFrameBuffer_async
		__func(self.handle, _frameBuffer, _asyncHandler, _ctx)


	def getScreenSize(self):
		_ScreenSize = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getScreenSize
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ScreenSize))

		if result > 0:
			raise PhidgetException(result)

		return _ScreenSize.value

	def setScreenSize(self, ScreenSize):
		_ScreenSize = ctypes.c_int(ScreenSize)

		__func = PhidgetSupport.getDll().PhidgetLCD_setScreenSize
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _ScreenSize)

		if result > 0:
			raise PhidgetException(result)


	def getSleeping(self):
		_Sleeping = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getSleeping
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Sleeping))

		if result > 0:
			raise PhidgetException(result)

		return _Sleeping.value

	def setSleeping(self, Sleeping):
		_Sleeping = ctypes.c_int(Sleeping)

		__func = PhidgetSupport.getDll().PhidgetLCD_setSleeping
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Sleeping)

		if result > 0:
			raise PhidgetException(result)


	def getWidth(self):
		_Width = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetLCD_getWidth
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Width))

		if result > 0:
			raise PhidgetException(result)

		return _Width.value

	def writeBitmap(self, xPosition, yPosition, xSize, ySize, bitmap):
		_xPosition = ctypes.c_int(xPosition)
		_yPosition = ctypes.c_int(yPosition)
		_xSize = ctypes.c_int(xSize)
		_ySize = ctypes.c_int(ySize)
		_bitmap = (ctypes.c_uint8 * len(bitmap))(*bitmap)

		__func = PhidgetSupport.getDll().PhidgetLCD_writeBitmap
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _xPosition, _yPosition, _xSize, _ySize, ctypes.byref(_bitmap))

		if result > 0:
			raise PhidgetException(result)


	def writeBitmap_async(self, xPosition, yPosition, xSize, ySize, bitmap, asyncHandler):
		_xPosition = ctypes.c_int(xPosition)
		_yPosition = ctypes.c_int(yPosition)
		_xSize = ctypes.c_int(xSize)
		_ySize = ctypes.c_int(ySize)
		_bitmap = (ctypes.c_uint8 * len(bitmap))(*bitmap)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_writeBitmap_async
		__func(self.handle, _xPosition, _yPosition, _xSize, _ySize, ctypes.byref(_bitmap), _asyncHandler, _ctx)


	def writeText(self, font, xPosition, yPosition, text):
		_font = ctypes.c_int(font)
		_xPosition = ctypes.c_int(xPosition)
		_yPosition = ctypes.c_int(yPosition)
		_text = ctypes.create_string_buffer(text.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetLCD_writeText
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _font, _xPosition, _yPosition, ctypes.byref(_text))

		if result > 0:
			raise PhidgetException(result)


	def writeText_async(self, font, xPosition, yPosition, text, asyncHandler):
		_font = ctypes.c_int(font)
		_xPosition = ctypes.c_int(xPosition)
		_yPosition = ctypes.c_int(yPosition)
		_text = ctypes.create_string_buffer(text.encode('utf-8'))

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetLCD_writeText_async
		__func(self.handle, _font, _xPosition, _yPosition, ctypes.byref(_text), _asyncHandler, _ctx)




import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.FanMode import FanMode
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class PowerGuard(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def enableFailsafe(self, failsafeTime):
		_failsafeTime = ctypes.c_uint32(failsafeTime)

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_enableFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _failsafeTime)

		if result > 0:
			raise PhidgetException(result)


	def getMinFailsafeTime(self):
		_MinFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_getMinFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MinFailsafeTime.value

	def getMaxFailsafeTime(self):
		_MaxFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_getMaxFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFailsafeTime.value

	def getFanMode(self):
		_FanMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_getFanMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_FanMode))

		if result > 0:
			raise PhidgetException(result)

		return _FanMode.value

	def setFanMode(self, FanMode):
		_FanMode = ctypes.c_int(FanMode)

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_setFanMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _FanMode)

		if result > 0:
			raise PhidgetException(result)


	def getOverVoltage(self):
		_OverVoltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_getOverVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_OverVoltage))

		if result > 0:
			raise PhidgetException(result)

		return _OverVoltage.value

	def setOverVoltage(self, OverVoltage):
		_OverVoltage = ctypes.c_double(OverVoltage)

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_setOverVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _OverVoltage)

		if result > 0:
			raise PhidgetException(result)


	def getMinOverVoltage(self):
		_MinOverVoltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_getMinOverVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinOverVoltage))

		if result > 0:
			raise PhidgetException(result)

		return _MinOverVoltage.value

	def getMaxOverVoltage(self):
		_MaxOverVoltage = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_getMaxOverVoltage
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxOverVoltage))

		if result > 0:
			raise PhidgetException(result)

		return _MaxOverVoltage.value

	def getPowerEnabled(self):
		_PowerEnabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_getPowerEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PowerEnabled))

		if result > 0:
			raise PhidgetException(result)

		return _PowerEnabled.value

	def setPowerEnabled(self, PowerEnabled):
		_PowerEnabled = ctypes.c_int(PowerEnabled)

		__func = PhidgetSupport.getDll().PhidgetPowerGuard_setPowerEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _PowerEnabled)

		if result > 0:
			raise PhidgetException(result)


	def resetFailsafe(self):
		__func = PhidgetSupport.getDll().PhidgetPowerGuard_resetFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)

